#
# spec file for package librelp
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define library_name librelp0
Name:           librelp
Version:        1.2.12
Release:        1.3
Summary:        A reliable logging library
License:        GPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://www.librelp.com/
Source:         http://download.rsyslog.com/librelp/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1110
BuildRequires:  pkgconfig(gnutls) >= 2.0.0
%else
BuildRequires:  libgnutls-devel >= 2.0.0
%endif

%description
librelp is an easy to use library for the RELP protocol. RELP in turn provides
reliable event logging over the network (and consequently RELP stands for
Reliable Event Logging Protocol). RELP was initiated by Rainer Gerhards after
he was finally upset by the lossy nature of plain tcp syslog and wanted a cure
for all these dangling issues.

RELP (and hence) librelp assures that no message is lost, not even when
connections break and a peer becomes unavailable. The current version of RELP
has a minimal window of opportunity for message duplication after a session has
been broken due to network problems. In this case, a few messages may be
duplicated (a problem that also exists with plain tcp syslog). Future versions
of RELP will address this shortcoming.

Please note that RELP is a general-purpose, extensible logging protocol. Even
though it was designed to solve the urgent need of rsyslog-to-rsyslog
communication, RELP supports many more applications. Extensible command verbs
provide ample opportunity to extend the protocol without affecting existing
applications.

%package -n %{library_name}
Summary:        A reliable logging library
Group:          Development/Libraries/C and C++

%description -n %{library_name}
librelp is an easy to use library for the RELP protocol. RELP in turn provides
reliable event logging over the network (and consequently RELP stands for
Reliable Event Logging Protocol). RELP was initiated by Rainer Gerhards after
he was finally upset by the lossy nature of plain tcp syslog and wanted a cure
for all these dangling issues.

RELP (and hence) librelp assures that no message is lost, not even when
connections break and a peer becomes unavailable. The current version of RELP
has a minimal window of opportunity for message duplication after a session has
been broken due to network problems. In this case, a few messages may be
duplicated (a problem that also exists with plain tcp syslog). Future versions
of RELP will address this shortcoming.

Please note that RELP is a general-purpose, extensible logging protocol. Even
though it was designed to solve the urgent need of rsyslog-to-rsyslog
communication, RELP supports many more applications. Extensible command verbs
provide ample opportunity to extend the protocol without affecting existing
applications.

%package devel
Summary:        A reliable logging library
Group:          Development/Libraries/C and C++
Requires:       %{library_name} = %{version}
Requires:       libgnutls-devel >= 1.4.0

%description devel
librelp is an easy to use library for the RELP protocol. RELP in turn provides
reliable event logging over the network (and consequently RELP stands for
Reliable Event Logging Protocol). RELP was initiated by Rainer Gerhards after
he was finally upset by the lossy nature of plain tcp syslog and wanted a cure
for all these dangling issues.

RELP (and hence) librelp assures that no message is lost, not even when
connections break and a peer becomes unavailable. The current version of RELP
has a minimal window of opportunity for message duplication after a session has
been broken due to network problems. In this case, a few messages may be
duplicated (a problem that also exists with plain tcp syslog). Future versions
of RELP will address this shortcoming.

Please note that RELP is a general-purpose, extensible logging protocol. Even
though it was designed to solve the urgent need of rsyslog-to-rsyslog
communication, RELP supports many more applications. Extensible command verbs
provide ample opportunity to extend the protocol without affecting existing
applications.

%prep
%setup -q

%build
%configure \
  --disable-static \
  --with-pic
make %{?_smp_mflags} V=1

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm %{buildroot}%{_libdir}/librelp.la

%post   -n %{library_name} -p /sbin/ldconfig
%postun -n %{library_name} -p /sbin/ldconfig

%files -n librelp0
%defattr(-,root,root,-)
%{_libdir}/librelp.so.*

%files devel
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README doc/*.html
%{_includedir}/librelp.h
%{_libdir}/librelp.so
%{_libdir}/pkgconfig/relp.pc

%changelog
* Mon Jan 30 2017 ndas@suse.com
- This updated library is needed for latest rsyslog(fate#320546)
* Sun Jul 10 2016 astieger@suse.com
- librelp 1.2.12:
  * API enhancement: permit to set connection timeout
  * cleanup: replace deprecated GnuTLS data types by current ones
* Tue Jun 28 2016 astieger@suse.com
- librelp 1.2.11:
  * do not accept more than one "open" verb on a connection
  * fix potential segfault when high-numbered fd is used in sender
  * make librelp not run in thight loop when out of sockets
  * flush the current recv frame if it exists if the client session
    is restarting
  * API enhancement: add configurable connection timeout
* Mon Apr  4 2016 astieger@suse.com
- librelp 1.2.10:
  * fix a problem with sending large buffers
  * improve sender/receiver code
  * enable compatibility with older versions of GnuTLS
* Mon Feb  8 2016 mpluskal@suse.com
- Make building more verbose
* Thu Jan 28 2016 mrueckert@suse.de
- fix build on sle11. the sles_version conditional is just broken
* Sat Jan  2 2016 astieger@suse.com
- librelp 1.2.9:
  * Ignoring return status when handling syslog frames now.
    Otherwise valid messages in the frame buffer will get lost when
    the remote connection is closed during meantime.
* Tue Sep  8 2015 astieger@suse.com
- librelp 1.2.8:
  * fix segfault if KEEPALIVE is used
* Tue Apr 29 2014 andreas.stieger@gmx.de
- update to 1.2.7
  - bugfix: librelp was incompatible with C++ without a real reason
  - bugfix: potential misadressing in wildcard match
  - bugfix: always last wildcard match was reported, not first
- contains changes from 1.2.6
  - report error when preparing for non-anon TLS and this is
    unsupported
* Thu Mar 20 2014 andreas.stieger@gmx.de
- update to 1.2.5:
  - permit to use anonymous TLS on platforms where GnuTLS lacks
    certificate verification function
* Mon Mar 17 2014 andreas.stieger@gmx.de
- update to 1.2.4:
  - correct API/ABI change in 1.2.3
  - revert back to previous state (return void)
  * relpSrvEnableTLS();
  * relpSrvEnableTLSZip();
    These functions are now deprecated.
  - introduce new functions that return a state
  * relpSrvEnableTLS2();
  * relpSrvEnableTLSZip2();
* Fri Mar 14 2014 andreas.stieger@gmx.de
- update to 1.2.3:
  - add ability to build librelp without TLS
  - API change: two functions that used to return void now return
    state:
  * relpSrvEnableTLS();
  * relpSrvEnableTLSZip();
* Tue Jan 14 2014 andreas.stieger@gmx.de
- update to 1.2.2:
  - add capability to enable tcp KEEPALIVE
  - introduced new API relpSrvSetKeepAlive() to support KEEPALIVE
  - errors binding listener port are now reported via error message
    callback
* Tue Jul 16 2013 andreas.stieger@gmx.de
- update to 1.2.0:
  - support for epoll() added
  - API extension: relpEngineSetOnGenericErr
* Thu Jul 11 2013 andreas.stieger@gmx.de
- update to 1.1.5:
  This is a bug-fixing release that takes care of a memory leak on
  connection close as well as potential misadressing on session
  close.
  - bugfix: memory leak on connection close
  - bugfix: potential misadressing on session close
* Thu Jul 11 2013 andreas.stieger@gmx.de
- update to 1.1.4:
  This version of the library provides certificate wildcard name
  checks. It also supports enhanced performance options (burst
  support, requires support from the caller). It also contains
  some bug fixes, especially for BSD.
  - fix build problems on BSD
  - add ability to specify a non-standard RELP Window size
  - add burst support to the client API
  - wildcards are now supported in TLS name peer authentication
  - new APIs: relpCltHintBurstBegin, relpCltHintBurstEnd,
    relpCltSetWindowSize
* Sun Jun 30 2013 andreas.stieger@gmx.de
- update to 1.1.3:
  - increased performance of RELP connection
  - bugfix: potential segfault if no GnuTLS priority string was set
- includes changes from 1.1.2:
  - add capability to specify the GnuTLS priority string
    This gives callers complete control over crypto parameters, like
    ciphers to use.
  - add certificate-based authentication
  - add capability to specify number of Diffie-Hellman bits to use
  - API extension: relpSrvSetDHBits, relpSrvSetGnuTLSPriString,
    relpSrvSetGnuTLSPriString, relpCltSetGnuTLSPriString
    relpEngineSetOnAuthErr, relpCltSetUsrPtr,
    relpSrvSetAuthMode, relpCltSetAuthMode
- includes changes from 1.1.1:
  - added compression support for TLS
  - API extension: relpCltEnableTLSZip, relpSrvEnableTLSZip
- includes changes from 1.1.0
  - add TLS support
-   new api for creating listners:
    ... which permits us to set various properties before the listener
    is actually started. New callers should use it. Sequence is:
  * relpEngineListnerConstruct()
  * ... set properties ... (via relpSrv...() family)
  * relgEngineListnerConstructFinalize()
    This new style permits us to add/set additional listner options
    without the need to introduce ever-new listner create functions.
    Actually, their number would grow exponentionally, so this were
    a dead end.
    The old-style APIs relpEngineAddListner() and
    relpEngineAddListner2() are still fully supported (and supposed
    to be for a long time), but flagged as deprecated.
- includes changes from 1.0.7:
  - ABI change: removed relpCltConnect2() API which was against
    librelp API philosophy
    This was only introduced in 1.0.6 and been in the code for a very
    short time. So we decided that the best thing to do is actually
    remove it (there is NO known released user, this changes was for
    yet unreleased rsyslog 7.5.0).
- includes changes from 1.0.6:
  - enhanced API to permit binding a client to a specific IP address
- includes changes from 1.0.5:
  - bugfix: compile problem on Solaris
- includes changes from 1.0.4:
  - bugfix: busy loop on syslog sending as a client when server did not
    accept data; this was broken out only when the remote peer
    indicated that the connection as whole was broken. Now we properly
    timeout.
- make -devel package require gnutls-devel to be useful
* Tue Apr 23 2013 andreas.stieger@gmx.de
- update to 1.0.3:
  - added relpCltSetTimeout() interface function
  - improved timeout handling
  - provide support for user-settable shutdown indicator
- includes changes from 1.0.2:
  - added capability to support only IPv4/v6 instead of both
* Mon Sep 24 2012 andreas.stieger@gmx.de
- update to upstream 1.0.1:
  - added capability to stop server without canceling its thread
  - bugfix: interrupt of select() was not properly handled
- add pkgconfig support
* Mon May 14 2012 cfarrell@suse.com
- license update: GPL-3.0+
  No indication of GPL-3.0 ^only^ files in package. Fedora also using
  GPL-3.0+
* Fri May 11 2012 jengelh@inai.de
- Remove redundant sections and tags from specfile
- Enable parallel build
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Apr 14 2010 mrueckert@suse.de
- update to version 1.0.0
  This version of librelp matured in practice and it is now time
  for a 1.0 release. Besides that, it includes a small number of
  changes:
  - bugfix: user callback never received remote IP address
  - bugfix: offers builder did use a fixed size string without
    bounds checking. I don't think this was a real issue as it was
    not exposed to the outside world, but now the buffer
    dynamically grows (which is the right thing to do). Thank to
    mterry for alerting me.
- additional changes from version 0.1.3
  - the callback on message reception did not contain a way to pass
    on a caller cookie (e.g. for an instance pointer). An
    additional interface has been added to support that.
  - cleaned up FDL license specifics
  - added libtool versioning
  - made librelp compile out of the box on FreeBSD - thanks to
    Michael Biebl for the patch
- additional changes from version 0.1.2
  - forward compatibility changes in support of our plans to use
    the rsyslog runtime in the future
* Wed Apr  9 2008 mrueckert@suse.de
- initial package
